@@ -627,18 +627,18 @@ sub have_encoder_and_decoder {
     }
     eval "use $Class; 1"
     or do {
-        note("Could not locate $Class for testing" . ($@ ? " (Exception: $@)" : ""));
+        diag("Could not locate $Class for testing" . ($@ ? " (Exception: $@)" : ""));
         return();
     };
 
     eval "use $need_class; 1"
     or do {
-        note("Could not locate $need_class for testing" . ($@ ? " (Exception: $@)" : ""));
+        diag("Could not locate $need_class for testing" . ($@ ? " (Exception: $@)" : ""));
         return();
     };
     my $cmp_v = $need_class->VERSION;
     if ($min_v and $cmp_v < $min_v) {
-        note("Could not load correct version of $need_class for testing "
+        diag("Could not load correct version of $need_class for testing "
              ."(got: $cmp_v, needed at least $min_v)");
         return;
     }
@@ -646,7 +646,7 @@ sub have_encoder_and_decoder {
     $cmp_v = sprintf("%.2f", int($cmp_v*100)/100);
     my %compat_versions = map {$_ => 1} $Class->_test_compat();
     if (not defined $cmp_v or not exists $compat_versions{$cmp_v}) {
-        note("Could not load correct version of $need_class for testing "
+        diag("Could not load correct version of $need_class for testing "
              ."(got: $cmp_v, needed any of ".join(", ", keys %compat_versions).")");
         return();
     }
@@ -681,6 +681,10 @@ my $eng2= "1e3";
 
 my $sum= $eng0e0 + $eng0e1 + $eng2;
 
+sub encoder_required {
+    my ($ver, $name)= @_;
+    return "" . ( $Sereal::Encoder::VERSION < $ver ? "TODO " : "") . $name;
+}
 
 sub _get_roundtrip_tests {
     my @ScalarRoundtripTests = (
@@ -734,8 +738,8 @@ sub _get_roundtrip_tests {
             1023,1024,1025,
             8191,8192,8193,
         )),
-        ( map { [ ( $Sereal::Encoder::VERSION < 3.005002 ? "TODO" : "")
-                    . " troublesome num/strs '$_'", $_ ] } @numstr ),
+        ( map { [ encoder_required(3.005002, " troublesome num/strs '$_'"),
+                  $_ ] } @numstr ),
         ["long latin1 string", "üll" x 10000],
         ["long utf8 string", do {use utf8; " עדיין חשב" x 10000}],
         ["long utf8 string with only ascii", do {use utf8; "foo" x 10000}],
@@ -810,8 +814,27 @@ sub _get_roundtrip_tests {
         [ "undef", [\undef, \undef] ],
     );
 
+    my @blessed_array_check1;
+    $blessed_array_check1[0]= "foo";
+    $blessed_array_check1[1]= bless \$blessed_array_check1[0], "BlessedArrayCheck";
+    $blessed_array_check1[2]= \$blessed_array_check1[0];
+
+    my @blessed_array_check2= (3,0,0,3);
+    $blessed_array_check2[1]= \$blessed_array_check2[0];
+    $blessed_array_check2[2]= \$blessed_array_check2[3];
+    bless \$blessed_array_check2[0], "BlessedArrayCheck";
+    bless \$blessed_array_check2[3], "BlessedArrayCheck";
+
+    my @sc_array=(1,1);
+    $sc_array[0]=bless \$sc_array[1], "BlessedArrayLeft";
+    $sc_array[1]=bless \$sc_array[0], "BlessedArrayRight";
+
+
     my @RoundtripTests = (
         @ScalarRoundtripTests,
+        [ encoder_required(3.006006,"BlessedArrayCheck 1"), \@blessed_array_check1 ],
+        [ encoder_required(3.006006,"BlessedArrayCheck 2"), \@blessed_array_check2 ],
+        [ encoder_required(3.006006,"Scalar Cross Blessed Array"), \@sc_array ],
 
         ["[{foo => 1}, {foo => 2}] - repeated hash keys",
           [{foo => 1}, {foo => 2}] ],
